@@ -61,9 +61,11 @@ class UIService(ui_pb2_grpc.UIServicer, QtWidgets.QGraphicsObject):
         self._cfg = Config.init()
         self._db = Database.instance()
         db_file=self._cfg.getSettings(self._cfg.DEFAULT_DB_FILE_KEY)
+        db_jrnl_wal=self._cfg.getBool(Config.DEFAULT_DB_JRNL_WAL)
         db_status, db_error = self._db.initialize(
             dbtype=self._cfg.getInt(self._cfg.DEFAULT_DB_TYPE_KEY),
-            dbfile=db_file
+            dbfile=db_file,
+            dbjrnl_wal=db_jrnl_wal
         )
         if db_status is False:
             Message.ok(
@@ -653,10 +655,12 @@ class UIService(ui_pb2_grpc.UIServicer, QtWidgets.QGraphicsObject):
         _default_action = self._cfg.getInt(self._cfg.DEFAULT_ACTION_KEY)
         try:
             temp_cfg = json.loads(newconf.config)
-            if _default_action == Config.ACTION_DENY_IDX:
-                temp_cfg['DefaultAction'] = Config.ACTION_DENY
-            else:
+            if _default_action == Config.ACTION_ALLOW_IDX:
                 temp_cfg['DefaultAction'] = Config.ACTION_ALLOW
+            else:
+                temp_cfg['DefaultAction'] = Config.ACTION_DENY
+
+            print("Setting daemon DefaultAction to:", temp_cfg['DefaultAction'])
 
             newconf.config = json.dumps(temp_cfg)
         except Exception as e:
@@ -689,7 +693,10 @@ class UIService(ui_pb2_grpc.UIServicer, QtWidgets.QGraphicsObject):
                                  rule.name, rule.description, str(rule.enabled),
                                  str(rule.precedence), str(rule.nolog), rule.action, rule.duration,
                                  rule.operator.type, str(rule.operator.sensitive), rule.operator.operand,
-                                 rule.operator.data)
+                                 rule.operator.data,
+                                 str(datetime.fromtimestamp(rule.created).strftime("%Y-%m-%d %H:%M:%S"))
+                                 )
+
         elif kwargs['action'] == self.DELETE_RULE:
             self._db.delete_rule(kwargs['name'], kwargs['addr'])
 
